import React from 'react';
import { useId } from '@reach/auto-id';

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var QRCodeImpl = /*#__PURE__*/require('qr.js/lib/QRCode');

var ErrorCorrectionLevel;

(function (ErrorCorrectionLevel) {
  ErrorCorrectionLevel[ErrorCorrectionLevel["L"] = 1] = "L";
  ErrorCorrectionLevel[ErrorCorrectionLevel["M"] = 0] = "M";
  ErrorCorrectionLevel[ErrorCorrectionLevel["Q"] = 3] = "Q";
  ErrorCorrectionLevel[ErrorCorrectionLevel["H"] = 2] = "H";
})(ErrorCorrectionLevel || (ErrorCorrectionLevel = {}));

var QR = function QR(_ref) {
  var data = _ref.data,
      _ref$fgColor = _ref.fgColor,
      fgColor = _ref$fgColor === void 0 ? '#6067f1' : _ref$fgColor,
      _ref$bgColor = _ref.bgColor,
      bgColor = _ref$bgColor === void 0 ? '#ffffff00' : _ref$bgColor,
      _ref$ecLevel = _ref.ecLevel,
      ecLevel = _ref$ecLevel === void 0 ? 'L' : _ref$ecLevel,
      logo = _ref.logo,
      eyeAs = _ref.eyeAs,
      dotAs = _ref.dotAs,
      props = _objectWithoutPropertiesLoose(_ref, ["data", "fgColor", "bgColor", "ecLevel", "logo", "eyeAs", "dotAs"]);

  var id = useId(props.id);
  var logoMaskId = id + "-logo-mask";
  var qr = new QRCodeImpl(-1, ErrorCorrectionLevel[ecLevel]);
  qr.addData(typeof data === 'object' ? JSON.stringify(data) : data);
  qr.make();
  var cells = qr.modules;
  var size = cells.length;
  var img;

  if (!(logo != null && logo.hide)) {
    var numberOfCellsToCover = Math.floor(cells.length * 0.2);
    var width = (logo == null ? void 0 : logo.width) || numberOfCellsToCover + (numberOfCellsToCover % 2 === 0 ? 1 : 0);
    var height = (logo == null ? void 0 : logo.height) || width;
    var x = (size - width) / 2;
    var y = (size - height) / 2;
    var opacity = (logo == null ? void 0 : logo.opacity) || 1;
    var src = (logo == null ? void 0 : logo.image) || "data:image/svg+xml;utf8," + encodeURIComponent("<svg width=\"25\" height=\"25\" viewBox=\"0 0 710 705\" xmlns=\"http://www.w3.org/2000/svg\"><path fill=\"" + bgColor + "\" d=\"M0 0h710v705H0z\"/><path fill=\"" + fgColor + "\" d=\"M454.416 188.193C454.258 241.685 410.797 285 357.208 285c-53.59 0-97.05-43.315-97.208-96.807 0 0-3.503-18.079 15.18-58.318 31.939-68.792 80.762-98.557 80.762-98.557s52.935 33.24 84.462 98.557c16.54 34.266 14.012 58.318 14.012 58.318zm0 328.614C454.258 463.315 410.797 420 357.208 420c-53.59 0-97.05 43.315-97.208 96.807 0 0-3.503 18.079 15.18 58.318 31.939 68.792 80.762 98.557 80.762 98.557s52.935-33.24 84.462-98.557c16.54-34.266 14.012-58.318 14.012-58.318zm49.391-261.223c-53.492.158-96.807 43.619-96.807 97.208 0 53.59 43.315 97.05 96.807 97.208 0 0 18.079 3.503 58.318-15.18 68.792-31.939 98.557-80.762 98.557-80.762s-33.24-52.935-98.557-84.462c-34.266-16.54-58.318-14.012-58.318-14.012zm-297.614-1c53.492.158 96.807 43.619 96.807 97.208 0 53.59-43.315 97.05-96.807 97.208 0 0-18.079 3.503-58.318-15.18-68.792-31.939-98.557-80.762-98.557-80.762s33.24-52.935 98.557-84.462c34.266-16.54 58.318-14.012 58.318-14.012z\"/></svg>");
    img = React.createElement(React.Fragment, null, React.createElement("mask", {
      id: logoMaskId
    }, React.createElement("rect", {
      fill: "white",
      x: 0,
      y: 0,
      width: "100%",
      height: "100%"
    }), React.createElement("rect", {
      fill: "black",
      x: x,
      y: y,
      width: width,
      height: height
    })), React.createElement("image", {
      href: src,
      x: x,
      y: y,
      width: width,
      height: height,
      opacity: opacity
    }));
  }

  return React.createElement("svg", Object.assign({}, props, {
    id: id,
    viewBox: "0 0 " + size + " " + size,
    xmlns: "http://www.w3.org/2000/svg",
    shapeRendering: "geometricPrecision"
  }), React.createElement("rect", {
    x: 0,
    y: 0,
    width: "100%",
    height: "100%",
    fill: bgColor
  }), React.createElement("g", {
    mask: img ? "url(#" + logoMaskId + ")" : undefined
  }, cells.map(function (row, rowIndex) {
    return row.map(function (cell, cellIndex) {
      if (cell) {
        var isTopLeftEye = cellIndex <= 7 && rowIndex <= 7;
        var isTopRightEye = cellIndex >= cells.length - 7 && rowIndex <= 7;
        var isBottomLeftEye = cellIndex <= 7 && rowIndex >= row.length - 7;
        var isEye = isTopLeftEye || isTopRightEye || isBottomLeftEye;
        var cellInfo = {
          color: fgColor,
          left: cellIndex,
          top: rowIndex,
          size: 1,
          key: "row: " + rowIndex + "; col: " + cellIndex
        };

        if (isEye) {
          var isInnerEyeX = cellIndex >= 2 && cellIndex <= 4 || cellIndex >= cells.length - 6 && cellIndex <= cells.length - 2;
          var isInnerEyeY = rowIndex >= 2 && rowIndex <= 4 || rowIndex >= cells.length - 5 && rowIndex <= cells.length - 3;
          var isInnerEye = isInnerEyeX && isInnerEyeY;

          if (!isInnerEye) {
            var isLeft = cellIndex < row.length - 1 && cells[rowIndex][cellIndex + 1];
            var isRight = cellIndex > 0 && cells[rowIndex][cellIndex - 1];
            var isTop = rowIndex > 0 && cells[rowIndex - 1][cellIndex];
            var isBottom = rowIndex < cells.length - 1 && cells[rowIndex + 1][cellIndex];
            var isTopLeft = isBottom && !isTop && isLeft && !isRight;

            if (isTopLeft) {
              var Comp = eyeAs || QREye;
              return React.createElement(Comp, Object.assign({}, cellInfo, {
                baseId: id
              }));
            }
          }
        } else {
          var _Comp = dotAs || QRDot;

          return React.createElement(_Comp, Object.assign({}, cellInfo));
        }
      }

      return undefined;
    });
  })), img);
};

var QRDot = function QRDot(props) {
  return React.createElement("circle", {
    fill: props.color,
    cx: props.left + props.size / 2,
    cy: props.top + props.size / 2,
    r: props.size / 2 * 0.85
  });
};

var QREye = function QREye(props) {
  var maskId = props.baseId + "-eye-mask-" + props.left + "-" + props.top;
  return React.createElement(React.Fragment, null, React.createElement("mask", {
    id: maskId
  }, React.createElement("rect", {
    fill: "white",
    x: props.left,
    y: props.top,
    width: props.size * 7,
    height: props.size * 7,
    rx: props.size
  }), React.createElement("rect", {
    fill: "black",
    x: props.left + props.size,
    y: props.top + props.size,
    width: props.size * 5,
    height: props.size * 5,
    rx: props.size / 4
  })), React.createElement("rect", {
    mask: "url(#" + maskId + ")",
    fill: props.color,
    x: props.left,
    y: props.top,
    width: props.size * 7,
    height: props.size * 7,
    rx: props.size
  }), React.createElement("rect", {
    fill: props.color,
    x: props.left + 2,
    y: props.top + 2,
    width: props.size * 3,
    height: props.size * 3,
    rx: props.size / 4
  }));
};

export { QR };
//# sourceMappingURL=qr-react.esm.js.map
